.. _installation:

Installation
============

To install stella with pip::

	pip install stella
	

Alternatively you can install the current development version of stella::

        git clone https://github.com/afeinstein20/stella
	cd stella
	python setup.py install
